export declare type MojangServiceStatus = 'green' | 'yellow' | 'red';
export declare type MojangService = 'minecraft.net' | 'session.minecraft.net' | 'account.mojang.com' | 'authserver.mojang.com' | 'sessionserver.mojang.com' | 'api.mojang.com' | 'textures.minecraft.net' | 'mojang.com';
export interface UserProfileResponse {
    id: string;
    name: string;
    demo?: boolean;
    legacy?: boolean;
}
/**
 * The changedToAt field is a Java timestamp in milliseconds.
 */
export interface NameHistoryResponse {
    name: string;
    changedToAt?: number;
}
export interface SkinDataResponse {
    id: string;
    name: string;
    properties: [{
        name: string;
        value: string;
        signature?: string;
    }];
}
export declare class MinecraftAPIError extends Error {
}
export default class MinecraftAPI {
    readonly name: string;
    uuid?: string;
    currentName?: string;
    legacy: boolean;
    demo: boolean;
    history?: NameHistoryResponse[];
    skinData?: SkinDataResponse;
    constructor(name: string);
    fetchProfile(): Promise<UserProfileResponse>;
    fetchNamehistory(): Promise<NameHistoryResponse[]>;
    fetchSkinData(unsigned?: boolean): Promise<SkinDataResponse>;
    fetch(): Promise<void>;
    /**
     * Returns status of various Mojang services.
     */
    static getServiceStatus(): Promise<{
        [key in MojangService]: MojangServiceStatus;
    }[]>;
    /**
     * Returns a list of SHA1 hashes used to check server addresses against when the client tries to connect.
     */
    static getBlockedServers(): Promise<string>;
}
