"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_fetch_1 = __importDefault(require("node-fetch"));
class MinecraftAPIError extends Error {
}
exports.MinecraftAPIError = MinecraftAPIError;
class MinecraftAPI {
    constructor(name) {
        this.legacy = false;
        this.demo = false;
        this.name = name;
    }
    async fetchProfile() {
        const data = await node_fetch_1.default(`https://api.mojang.com/users/profiles/minecraft/${this.name}`).catch(() => null);
        if (!data)
            throw new MinecraftAPIError('Fetch error.');
        if (data.status !== 200)
            throw new MinecraftAPIError(`Status Code: ${data.status} | ${data.statusText}`);
        const profile = await data.json();
        this.uuid = profile.id;
        this.currentName = this.name;
        this.demo = profile.demo || false;
        this.legacy = profile.legacy || false;
        return profile;
    }
    async fetchNamehistory() {
        if (!this.uuid)
            throw new MinecraftAPIError();
        const data = await node_fetch_1.default(`https://api.mojang.com/user/profiles/${this.uuid}/names`).catch(() => null);
        if (!data)
            throw new MinecraftAPIError('Fetch error.');
        if (data.status !== 200)
            throw new MinecraftAPIError(`Status Code: ${data.status} | ${data.statusText}`);
        const nameHistory = await data.json();
        this.history = nameHistory;
        return nameHistory;
    }
    async fetchSkinData(unsigned = true) {
        if (!this.uuid)
            throw new MinecraftAPIError();
        const data = await node_fetch_1.default(`https://sessionserver.mojang.com/session/minecraft/profile/${encodeURIComponent(this.uuid)}?unsigned=${unsigned}`).catch(() => null);
        if (!data)
            throw new MinecraftAPIError('Fetch error.');
        if (data.status === 429)
            throw new MinecraftAPIError('TooManyRequestsException: The client has sent too many requests within a certain amount of time');
        if (data.status !== 200)
            throw new MinecraftAPIError(`Status Code: ${data.status} | ${data.statusText}`);
        const profile = await data.json();
        this.skinData = profile;
        return profile;
    }
    async fetch() {
        await this.fetchProfile();
        await this.fetchNamehistory();
        await this.fetchSkinData();
    }
    /**
     * Returns status of various Mojang services.
     */
    static async getServiceStatus() {
        const data = await node_fetch_1.default('https://status.mojang.com/check').catch(() => null);
        if (!data)
            throw new MinecraftAPIError('Fetch error.');
        if (data.status !== 200)
            throw new MinecraftAPIError(`Status Code: ${data.status} | ${data.statusText}`);
        const result = await data.json();
        return result;
    }
    /**
     * Returns a list of SHA1 hashes used to check server addresses against when the client tries to connect.
     */
    static async getBlockedServers() {
        const data = await node_fetch_1.default('https://sessionserver.mojang.com/blockedservers').catch(() => null);
        if (!data)
            throw new MinecraftAPIError('Fetch error.');
        if (data.status !== 200)
            throw new MinecraftAPIError(`Status Code: ${data.status} | ${data.statusText}`);
        return data.text();
    }
}
exports.default = MinecraftAPI;
